@@ -1,7 +1,7 @@
 package CPAN::Reporter;
 use strict;
 use vars qw/$VERSION/;
-$VERSION = '1.1708'; 
+$VERSION = '1.1709'; 
 $VERSION = eval $VERSION; ## no critic
 
 use Config;
@@ -423,8 +423,10 @@ END_SKIP_DIST
     my $tr = Test::Reporter->new;
     $tr->grade( $result->{grade} );
     $tr->distribution( $result->{dist_name}  );
-    # older T::R might not handle the distfile() method
-    $tr->distfile( $result->{dist}->pretty_id ) if $tr->can('distfile');
+    # Older Test::Reporter doesn't support distfile, but we need it for
+    # Metabase transport
+    $tr->distfile( $result->{dist}->pretty_id ) 
+      if $Test::Reporter::VERSION >= 1.54;
 
     # Skip if duplicate and not sending duplicates
     if ( $is_duplicate ) {
@@ -552,14 +554,23 @@ sub _downgrade_known_causes {
         $grade = 'na';
         $msg = 'This platform is not supported';
     }
+    # check for Makefile without 'test' target
+    elsif ( grep { /No rule to make target .test/ims } @{$output} ) {
+        $grade = 'unknown';
+        $msg = 'No make test target';
+    }
+    elsif ( grep { /don't know how to make test/ims } @{$output} ) {
+        $grade = 'unknown';
+        $msg = 'No make test target';
+    }
     # check the prereq report for missing or failure flag '!'
     elsif ( $grade ne 'pass' && $result->{prereq_pm} =~ m{n/a}ims ) {
         $grade = 'discard';
-        $msg = 'Prerequisite missing';
+        $msg = "Prerequisite missing:\n$result->{prereq_pm}";
     }
     elsif ( $grade ne 'pass' && $result->{prereq_pm} =~ m{^\s+!}ims ) {
         $grade = 'discard';
-        $msg = 'Prerequisite version too low';
+        $msg = "Prerequisite version too low:\n$result->{prereq_pm}";
     }
     # in PL stage -- if pass but no Makefile or Build, then this should 
     # be recorded as a discard
